# bookleter
##### Turns pdfs into a6 sized foldable booklets

## install
```console
$ pip install bookleter==0.1.0
```

## usage
```console
$ bookleter [pdfname] [start_page-end_page] [direction: rtl ltr] [margin percentage: 50]
```
### example
```console
$ bookleter my_book.pdf 1-30 rtl 50
```